@@ -32,7 +32,7 @@ typedef struct {
         
         /* widgets for global prefs */
         GtkSpinButton *timeout_spinbutton, *graph_size_spinbutton;
-        GtkTable *globals_table;
+        GtkGrid *globals_grid;
         GtkHSeparator *globals_separator;
         GtkComboBoxText *display_mode_combo_box, *layout_mode_combo_box, *temperature_scale_combo_box;
         GtkLabel *timeout_label, *display_mode_label, *layout_mode_label, *temperature_scale_label, *graph_size_label, *update_header, *display_header;
